# NLS

[[_TOC_]]

# Docker

## Load Images

First copy `nls-X.Y.Z-bios.zip` to `/opt/nls-X.Y.Z-bios.zip` with SFTP/SSH.

```shell
# set version
export VERSION=3.4.1
# extract archive
unzip nls-$VERSION-bios.zip
# goto directory
cd nls-$VERSION-bios
```

Import Images into Docker:

```shell
# appliance
docker load --input dls_appliance_$VERSION.tar.gz
# postgres
docker load --input dls_pgsql_$VERSION.tar.gz
# upgrade-image (optional)
docker load --input dls_upgrade_$VERSION.tar.gz
```

## Start service

```shell
cd docker
docker compose up -d
````

## Dump Filestructure

Prepare output:

```shell
mkdir /tmp/out
```

Show running containers:

```shell
docker container ls
```

Copy directory structure (using container-id from `dls:appliance_$VERSION`)

```shell
docker cp -a <container-id>:/venv/lib /tmp/out
# Successfully copied ...MB to /tmp/out/
```

Now you have the required directory structure in `/tmp/out/lib/python?.??/site-packages`.

## Re-Tag Images and upload to this registry

Show Images:

```shell
docker image ls
````

Tag Images:

```shell
docker image tag <image-id-dls_appliance> registry.git.collinwebdesigns.de/nvidia/nls/appliance:$VERSION
docker image tag <image-id-dls_pgsql> registry.git.collinwebdesigns.de/nvidia/nls/pgsql:$VERSION
docker image tag <image-id-dls_upgrade> registry.git.collinwebdesigns.de/nvidia/nls/upgrade:$VERSION
```

Upload Images:

```shell
# Login to private registry
docker login registry.git.collinwebdesigns.de
# Push images
docker image push registry.git.collinwebdesigns.de/nvidia/nls/appliance:$VERSION
docker image push registry.git.collinwebdesigns.de/nvidia/nls/pgsql:$VERSION
docker image push registry.git.collinwebdesigns.de/nvidia/nls/upgrade:$VERSION
```